==> clixon-6.5.0.tar.gz: clixon-6.5.0/apps/cli/cli_plugin.h <==
/*
 *
  ***** BEGIN LICENSE BLOCK *****
 
  Copyright (C) 2009-2016 Olof Hagsand and Benny Holmgren
  Copyright (C) 2017-2019 Olof Hagsand
  Copyright (C) 2020-2022 Olof Hagsand and Rubicon Communications, LLC(Netgate)

  This file is part of CLIXON.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.

  Alternatively, the contents of this file may be used under the terms of
  the GNU General Public License Version 3 or later (the "GPL"),
  in which case the provisions of the GPL are applicable instead
  of those above. If you wish to allow use of your version of this file only
  under the terms of the GPL, and not to allow others to
  use your version of this file under the terms of Apache License version 2, 
  indicate your decision by deleting the provisions above and replace them with
  the  notice and other provisions required by the GPL. If you do not delete
  the provisions above, a recipient may use your version of this file under
  the terms of any one of the Apache License version 2 or the GPL.

  ***** END LICENSE BLOCK *****

 */

#ifndef _CLI_PLUGIN_H_
#define _CLI_PLUGIN_H_

#include <stdio.h>
#include <inttypes.h>
#include <netinet/in.h>

/* clicon generic callback pointer */
typedef void (clicon_callback_t)(clicon_handle h);


void *clixon_str2fn(char *name, void *handle, char **error);

int clicon_parse(clicon_handle h, char *cmd, char **mode, cligen_result *result, int *evalres);

int clicon_cliread(clicon_handle h, pt_head *ph, char **stringp);

int cli_plugin_finish(clicon_handle h);

#endif  /* _CLI_PLUGIN_H_ */

==> clixon-7.0.0.tar.gz: clixon-7.0.0/apps/cli/cli_plugin.h <==
/*
 *
  ***** BEGIN LICENSE BLOCK *****
 
  Copyright (C) 2009-2016 Olof Hagsand and Benny Holmgren
  Copyright (C) 2017-2019 Olof Hagsand
  Copyright (C) 2020-2022 Olof Hagsand and Rubicon Communications, LLC(Netgate)

  This file is part of CLIXON.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.

  Alternatively, the contents of this file may be used under the terms of
  the GNU General Public License Version 3 or later (the "GPL"),
  in which case the provisions of the GPL are applicable instead
  of those above. If you wish to allow use of your version of this file only
  under the terms of the GPL, and not to allow others to
  use your version of this file under the terms of Apache License version 2, 
  indicate your decision by deleting the provisions above and replace them with
  the  notice and other provisions required by the GPL. If you do not delete
  the provisions above, a recipient may use your version of this file under
  the terms of any one of the Apache License version 2 or the GPL.

  ***** END LICENSE BLOCK *****

 */

#ifndef _CLI_PLUGIN_H_
#define _CLI_PLUGIN_H_

#include <stdio.h>
#include <inttypes.h>
#include <netinet/in.h>

/* clicon generic callback pointer */
typedef void (clicon_callback_t)(clixon_handle h);


void *clixon_str2fn(char *name, void *handle, char **error);

int clicon_parse(clixon_handle h, char *cmd, char **mode, cligen_result *result, int *evalres);

int clicon_cliread(clixon_handle h, pt_head *ph, char **stringp);

int cli_plugin_finish(clixon_handle h);

#endif  /* _CLI_PLUGIN_H_ */
